;; Generated package description from tmr.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "tmr" "1.3.0.0.20260529.24" "Set timers using a convenient notation" '((emacs "29.1")) :commit "ce6a462acd7459a732538192c71b5166ba0a8ee1" :authors '(("Protesilaos" . "info@protesilaos.com") ("Damien Cassou" . "damien@cassou.me") ("Daniel Mendler" . "mail@daniel-mendler.de") ("Steven Allen" . "steven@stebalien.com")) :maintainer '("Protesilaos" . "info@protesilaos.com") :keywords '("convenience" "timer") :url "https://github.com/protesilaos/tmr")
